@@ -8,12 +8,12 @@ collect_species <- function(.query, file = NULL){
     .query$file <- check_download_filename(file, ext = "csv")
     query_API(.query)
     result <- read_csv(.query$file, col_types = cols()) # NOTE: used to have tryCatch()
-    if(nrow(result) > 0 && 
+    if(nrow(result) > 0 &&
        pour("atlas", "region", .pkg = "galah") == "Australia"){
-      names(result) <- rename_columns(names(result), 
+      names(result) <- rename_columns(names(result),
                                       type = "checklist")
-      result <- result[, wanted_columns("checklist")]
+      result <- result[, colnames(result) %in% wanted_columns("checklist")]
     }
     result
   }
-}
+}
\ No newline at end of file
