@@ -176,14 +176,16 @@ test_that("galah_filter handles lsid as an input", {
   ids <- c("https://biodiversity.org.au/afd/taxa/0df99ece-1982-4605-a2b3-4fcb7660ee2b",
            "https://id.biodiversity.org.au/node/apni/2910467",
            "https://id.biodiversity.org.au/node/apni/291047") # wrong id
-  q_set <- galah_call() |>
+  query <- galah_call() |>
     # galah_identify(ids, search = FALSE) |>
     galah_filter(year == 2020,
                  lsid == ids) |>
     count() |>
     collapse()
   # number of taxa searches is 3, not 4
-  expect_equal(length(q_set), 3)
+  expect_s3_class(query, "query")
+  expect_equal(length(query), 5)
+  expect_equal(names(query), c("type", "url", "slot_name", "expand", "headers"))
 })
 
 test_that("galah_filter handles different fields separated by OR", {
