@@ -7,28 +7,36 @@ test_that("swapping to atlas = France works", {
 
 test_that("show_all(fields) works for France", {
   skip_if_offline()
-  x <- show_all(fields)
+  x <- show_all(fields) |>
+    try(silent = TRUE)
+  skip_if(inherits(x, "try-error"), message = "API not available")
   expect_gt(nrow(x), 1)
   expect_true(inherits(x, c("tbl_df", "tbl", "data.frame")))
 })
 
 test_that("show_all(collections) works for France", {
   skip_if_offline()
-  x <- show_all(collections, limit = 10)
+  x <- show_all(collections, limit = 10) |>
+    try(silent = TRUE)
+  skip_if(inherits(x, "try-error"), message = "API not available")
   expect_lte(nrow(x), 10)
   expect_true(inherits(x, c("tbl_df", "tbl", "data.frame")))
 })
 
 test_that("show_all(datasets) works for France", {
   skip_if_offline()
-  x <- show_all(datasets, limit = 10)
+  x <- show_all(datasets, limit = 10) |>
+    try(silent = TRUE)
+  skip_if(inherits(x, "try-error"), message = "API not available")
   expect_lte(nrow(x), 10)
   expect_true(inherits(x, c("tbl_df", "tbl", "data.frame")))
 })
 
 test_that("show_all(providers) works for France", {
   skip_if_offline()
-  x <- show_all(providers, limit = 10)
+  x <- show_all(providers, limit = 10) |>
+    try(silent = TRUE)
+  skip_if(inherits(x, "try-error"), message = "API not available")
   expect_lte(nrow(x), 10) # no data stored by this atlas at present
   expect_true(inherits(x, c("tbl_df", "tbl", "data.frame")))
 })
@@ -39,7 +47,9 @@ test_that("show_all(reasons) fails for France", {
 
 test_that("show_all(assertions) works for France", {
   skip_if_offline()
-  x <- show_all(assertions)
+  x <- show_all(assertions) |>
+    try(silent = TRUE)
+  skip_if(inherits(x, "try-error"), message = "API not available")
   expect_gt(nrow(x), 1)
   expect_true(inherits(x, c("tbl_df", "tbl", "data.frame")))
 })
@@ -54,14 +64,18 @@ test_that("show_all(lists) fails for France", {
 
 test_that("search_all(fields) works for France", {
   skip_if_offline()
-  x <- search_all(fields, "year")
+  x <- search_all(fields, "year") |>
+    try(silent = TRUE)
+  skip_if(inherits(x, "try-error"), message = "API not available")
   expect_gte(nrow(x), 1)
   expect_true(inherits(x, c("tbl_df", "tbl", "data.frame")))
 })
 
 test_that("search_all(taxa) works for France", {
   skip_if_offline()
-  x <- search_all(taxa, "Vulpes vulpes")
+  x <- search_all(taxa, "Vulpes vulpes") |>
+    try(silent = TRUE)
+  skip_if(inherits(x, "try-error"), message = "API not available")
   expect_gte(nrow(x), 1)
   expect_true(inherits(x, c("tbl_df", "tbl", "data.frame")))
 })
@@ -69,18 +83,28 @@ test_that("search_all(taxa) works for France", {
 test_that("show_values works for France", {
   skip_if_offline()
   x <- search_fields("basisOfRecord") |> 
-      show_values()
+      show_values() |>
+    try(silent = TRUE)
+  skip_if(inherits(x, "try-error"), message = "API not available")
   expect_gt(nrow(x), 1)
 })
 
 test_that("atlas_counts works for France", {
   skip_if_offline()
-  expect_gt(atlas_counts()$count, 0)
+  x <- atlas_counts() |>
+    pull(count) |>
+    try(silent = TRUE)
+  skip_if(inherits(x, "try-error"), message = "API not available")
+  expect_gt(x, 0)
 })
 
-test_that("atlas_counts works for France", {
+test_that("atlas_counts works with type = 'species' for France", {
   skip_if_offline()
-  expect_gt(atlas_counts(type = "species")$count, 0)
+  x <- atlas_counts(type = "species") |>
+    pull(count) |>
+    try(silent = TRUE)
+  skip_if(inherits(x, "try-error"), message = "API not available")
+  expect_gt(x, 0)
 })
 
 test_that("atlas_counts works with galah_identify for France", {
@@ -88,11 +112,15 @@ test_that("atlas_counts works with galah_identify for France", {
   result <- galah_call() |>
     identify("Mammalia") |>
     count() |>
-    collect()
+    collect() |>
+    try(silent = TRUE)
+  skip_if(inherits(result, "try-error"), message = "API not available")
   result2 <- galah_call() |>
     filter(class == "Mammalia") |>
     count() |>
-    collect()
+    collect() |>
+    try(silent = TRUE)
+  skip_if(inherits(result2, "try-error"), message = "API not available")
   expect_lt(
     sqrt((result2$count - result$count)^2) / result$count,
     0.1) # i.e. <1% margin of error
@@ -104,7 +132,9 @@ test_that("atlas_counts works with group_by for France", {
     filter(year >= 2018) |>
     group_by(year) |>
     count() |>
-    collect()
+    collect() |>
+    try(silent = TRUE)
+  skip_if(inherits(result, "try-error"), message = "API not available")
   expect_gt(nrow(result), 1)
   expect_equal(names(result), c("year", "count"))
 })
@@ -114,7 +144,9 @@ test_that("atlas_species works for France", {
   galah_config(email = "ala4r@ala.org.au")
   x <- galah_call(type = "species") |>
     identify("Lagomorpha") |>
-    collect()
+    collect() |>
+    try(silent = TRUE)
+  skip_if(inherits(x, "try-error"), message = "API not available")
   expect_true(inherits(x, c("tbl_df", "tbl", "data.frame")))
   expect_gt(nrow(x), 1)
   expect_gt(ncol(x), 1)
@@ -127,7 +159,9 @@ test_that("atlas_occurrences works for France", {
     filter(year <= 1950) |>
     identify("Vulpes vulpes") |>
     select(species, year) |>
-    collect()
+    collect() |>
+    try(silent = TRUE)
+  skip_if(inherits(x, "try-error"), message = "API not available")
   expect_true(inherits(x, c("tbl_df", "tbl", "data.frame")))
   expect_gt(nrow(x), 1)
   expect_equal(names(x), c("species", "year"))
